Play the Game of Nim

- valid8 - localpackage: packagebase: ../../ paths: - ../../source/playing/cli/play.py - ../../source/playing/cli/ansi.py - ../../source/playing/web/play.py - ../../source/playing/web/playscript.py - ../../source/version.py - ../../source/typedefs.py - ../../source/calculations.py - ../../source/core.py - ../../__init__.py from source.playing.web import playscript playscript.main_dynamics()

# The Game of Nim

Powered by the source PyPi package nimgame